==> zmailer-2.99.25-960120.tar.gz: zmailer-2.99.25/router/prototypes.h <==
/* Various prototypes for ROUTER of Zmailer */

#ifndef	__
# ifdef __STDC__
#  define __(x) x
# else
#  define __(x) ()
#  define const
#  define volatile
# endif
#endif

#ifdef  USE_SETUIDX	/* IBM AIXism */
# include <sys/id.h>
# ifdef USE_SETREUID
#  define  setreuid(x,y) setuidx(ID_REAL|ID_EFFECTIVE, y)
# else /* !USE_SETREUID */
#  define  setuid(y)     setuidx(ID_REAL|ID_EFFECTIVE, y)
# endif
#endif

/* various libraries, standard libc included.. */

extern char	*erraddrlog;
extern char	*gs_name;
extern char	*monthname[];
extern char	*myhostname;
extern char	*optarg;
extern char	*prio_list[];
extern char	*progname;
extern char	*rfc822tz __(());
extern char	*sb_retrieve __(());
extern char	*strerror __((const int errno));
extern int	D_hdr_rewrite;
extern int	D_router;
extern int	cistrcmp();
extern int	cistrncmp();
extern char	*strchr(), *strrchr();
extern int	strmatch();
extern int	apply();
extern int	lapply();
extern int	deferit;
extern int	fprintToken();
extern int	gensym;
extern int	opterr;
extern int	optind;
extern int	printToken();
extern int	wanttabs;
extern struct headerinfo *find_header();
extern struct headerinfo *find_header();
extern struct headerinfo envelope_hdrs[];
extern struct headerinfo mandatory_hdrs[];
extern struct token * scan822 __((u_char **cpp, long n, int c1, int c2,
				  int allowcomments, struct token **tlistp));
extern char *rfc822date __((time_t *tim));
extern union misc parse822();
extern void	dumpHeader();
extern void	hdr_print();
extern void	sb_external();
extern void	sb_external();
extern void	v_set();
extern void	v_setl();
#if	!defined(tolower) && !defined(sgi) /* XX: should use string.h or some such .. */
extern int	tolower __((const int));
#endif

/* File: conf.c */
extern char	 files_gid;
extern char	*cf_suffix;
extern char	*default_trusted[];
extern char	*err_prio_list[];
extern char	*files_group;
extern char	*logdir;
extern char	*prio_list[];
extern char	*trusted_group;
extern int	 filepriv_mask_reg;
extern int	 filepriv_mask_dir;
extern int	 maxReceived;
extern int	 real_stability;
extern int	 stability;
extern int	 wanttabs;
extern u_int	 sweepintvl;
extern struct sptree	*spt_databases, *spt_files, *spt_modcheck,
			*spt_goodguys, *spt_uidmap, *spt_loginmap,
			*spt_fullnamemap, *spt_incoredbs, *spt_headers,
			*spt_eheaders, *spt_builtins, *spt_funclist;
extern struct sptree_init splaytrees[];

/* File: dateparse.c */
extern long	dateParse __((struct tm *localtmptr, struct token *t));

/* File: db.c */
extern int	run_relation __((int argc, char **argv));
extern struct sptree *icdbspltree __((char *name));
extern int	run_db __((int argc, char **argv));
extern struct conscell	*db __((u_char *dbname, u_char *key));
extern char    *dbfile __((u_char *dbname));
extern void	dbfree __((void));
extern char    *dbtype __((u_char *dbname));

/* File: functions.c */
extern int	funclevel;

extern int	D_sequencer;
extern int	D_hdr_rewrite;
extern int	D_router;
extern int	D_functions;
extern int	D_compare;
extern int	D_matched;
extern int	D_assign;
extern int	D_final;
extern int	D_db;
extern int	D_alias;
extern int	D_bind;
extern int	D_resolv;
extern int	D_alloc;
extern int	D_regnarrate;

extern int run_trace __((int argc, char *argv[]));
extern char *erraddrlog;
extern SIGNAL_TYPE sig_hup __((int));
extern int	run_daemon __((int argc, char *argv[]));
extern int	gensym;
extern char	*gs_name;
extern void	optsave __((int type, struct envelope *e));

/* File: rfc822.c */
extern char	*errors_to;

extern int	run_rfc822 __((int argc, char **argv));
extern int	makeLetter __((struct envelope *e, int octothrp));
extern void	dumpInfo __((struct envelope *e));
extern void	dumpHeaders __((struct header *h));
extern void	dumpHeader __((struct header *h));
extern int	isSenderAddr;
extern int	isRecpntAddr;
extern void	squirrel __((struct envelope *e, char *text));
extern struct header	*erraddress __((struct envelope *e));
extern void	reject __((struct envelope *e, char *msgfile));
extern void	defer __((struct envelope *e));
extern struct header	*mkSender __((struct envelope *e, u_char *name, int flag));
extern struct header	*mkTrace __((struct envelope *e));
extern int	nullhost __((u_char *s));
extern struct conscell	*pickaddress __((struct conscell *l));
extern int	thesender __((struct envelope *e, struct address *a));
extern struct conscell	*makequad __((void));
extern int	iserrmessage __((void));
extern int	sequencer __((struct envelope *e, char *file));

/* File: rfc822hdrs.c */
extern union misc	 hdr_scanparse __((struct envelope *e, struct header *h, int commentflag));
extern struct header	*makeHeader __((struct sptree *db, u_char *s, int len));
extern struct headerinfo *senderDesc __((void));
extern void	set_pname __((struct envelope *e, struct header *h, char *s));
extern struct header	*copySender __((struct envelope *e));
extern struct header	*copyRecipient __((struct header *h));
extern struct header	*mkMessageId __((struct envelope *e, time_t unixtime));
extern struct header	*mkToHeader  __((struct envelope *e, const char *buf));
extern struct header	*mkDate __((int isresent, time_t unixtime));
extern void	hdr_print __((struct header *h, FILE *fp));
extern int	hdr_nilp __((struct header *h));
extern void	pureAddress __((FILE *fp, struct addr *pp));
extern int	printAddress __((FILE *fp, struct addr *pp, int onlylength));
extern int	printLAddress __((FILE *fp, struct addr *pp, int col));
extern char    *saveAddress __((struct addr *pp));
extern void	errprint __((FILE *fp, struct addr *pp, int hdrlen));
extern HeaderStamp hdr_type __((struct header *h));
extern struct header	*hdr_warning __((struct header *h));
extern void	hdr_errprint __((struct envelope *e, struct header *h, FILE *fp, char *msg));

/* File: rfc822walk.c */
extern struct address	*revaddress __((struct address *ap));
extern union misc	 parse822 __((HeaderSemantics entry, struct token **tlistp, struct tm *ltm, FILE *tfp));


/* File: router.c */
extern char *progname;
extern char *mailshare;
extern char *myhostname;
extern time_t now;
extern memtypes stickymem;
extern int   mustexit;
extern int   canexit;
extern int   deferit;
extern int   router_id;
extern int   savefile;

extern int	main __((int argc, char *argv[]));
extern int	login_to_uid __((u_char *name));
extern u_char	*uidpwnam __((int uid));
extern int	isgoodguy __((int uid));
extern void	logmessage __((struct envelope *e));

/* File: shliase.c */
extern int	s_apply __((int argc, char *argv[]));
extern int	n_apply __((char **cpp, int argc, char *argv[]));
extern struct header *hdr_rewrite __((u_char *name, struct header *h));
extern void	setenvinfo __((struct envelope *e));
extern struct conscell *router __((struct address *a, int uid, char *type));
extern struct conscell *crossbar __((struct conscell *from, struct conscell *to));

/* File: version.c */
extern char *Version;
extern char *CC_user;
extern char *CC_pwd;

==> zmailer-2.99.29-960717.tar.gz: zmailer-2.99.29/router/prototypes.h <==
/* Various prototypes for ROUTER of Zmailer */

#ifndef	__
# ifdef __STDC__
#  define __(x) x
# else
#  define __(x) ()
#  define const
#  define volatile
# endif
#endif

#ifdef  USE_SETUIDX	/* IBM AIXism */
# include <sys/id.h>
# ifdef USE_SETREUID
#  define  setreuid(x,y) setuidx(ID_REAL|ID_EFFECTIVE, y)
# else /* !USE_SETREUID */
#  define  setuid(y)     setuidx(ID_REAL|ID_EFFECTIVE, y)
# endif
#endif

/* various libraries, standard libc included.. */

extern char	*erraddrlog;
extern char	*gs_name;
extern char	*monthname[];
extern char	*myhostname;
extern char	*optarg;
extern char	*prio_list[];
extern char	*progname;
extern char	*rfc822tz __(());
extern char	*sb_retrieve __(());
extern char	*strerror __((const int errno));
extern int	D_hdr_rewrite;
extern int	D_router;
extern int	cistrcmp();
extern int	cistrncmp();
extern char	*strchr(), *strrchr();
extern int	strmatch();
extern int	apply();
extern int	lapply();
extern int	deferit;
extern int	fprintToken();
extern int	gensym;
extern int	opterr;
extern int	optind;
extern int	printToken();
extern int	wanttabs;
extern struct headerinfo *find_header();
extern struct headerinfo *find_header();
extern struct headerinfo envelope_hdrs[];
extern struct headerinfo mandatory_hdrs[];
extern struct token * scan822 __((u_char **cpp, long n, int c1, int c2,
				  int allowcomments, struct token **tlistp));
extern char *rfc822date __((time_t *tim));
extern union misc parse822();
extern void	dumpHeader();
extern void	hdr_print();
extern void	sb_external();
extern void	sb_external();
extern void	v_set();
extern void	v_setl();
#if	!defined(tolower) && !defined(sgi) /* XX: should use string.h or some such .. */
extern int	tolower __((const int));
#endif

/* File: conf.c */
extern char	 files_gid;
extern char	*cf_suffix;
extern char	*default_trusted[];
extern char	*err_prio_list[];
extern char	*files_group;
extern char	*logdir;
extern char	*prio_list[];
extern char	*trusted_group;
extern int	 filepriv_mask_reg;
extern int	 filepriv_mask_dir;
extern int	 maxReceived;
extern int	 real_stability;
extern int	 stability;
extern int	 wanttabs;
extern u_int	 sweepintvl;
extern struct sptree	*spt_databases, *spt_files, *spt_modcheck,
			*spt_goodguys, *spt_uidmap, *spt_loginmap,
			*spt_fullnamemap, *spt_incoredbs, *spt_headers,
			*spt_eheaders, *spt_builtins, *spt_funclist;
extern struct sptree_init splaytrees[];

/* File: dateparse.c */
extern long	dateParse __((struct tm *localtmptr, struct token *t));

/* File: db.c */
extern int	run_relation __((int argc, char **argv));
extern struct sptree *icdbspltree __((char *name));
extern int	run_db __((int argc, char **argv));
extern struct conscell	*db __((u_char *dbname, u_char *key));
extern char    *dbfile __((u_char *dbname));
extern void	dbfree __((void));
extern char    *dbtype __((u_char *dbname));

/* File: functions.c */
extern int	funclevel;

extern int	D_sequencer;
extern int	D_hdr_rewrite;
extern int	D_router;
extern int	D_functions;
extern int	D_compare;
extern int	D_matched;
extern int	D_assign;
extern int	D_final;
extern int	D_db;
extern int	D_alias;
extern int	D_bind;
extern int	D_resolv;
extern int	D_alloc;
extern int	D_regnarrate;

extern int run_trace __((int argc, char *argv[]));
extern char *erraddrlog;
extern RETSIGTYPE sig_hup __((int));
extern int	run_daemon __((int argc, char *argv[]));
extern int	gensym;
extern char	*gs_name;
extern void	optsave __((int type, struct envelope *e));

/* File: rfc822.c */
extern char	*errors_to;

extern int	run_rfc822 __((int argc, char **argv));
extern int	makeLetter __((struct envelope *e, int octothrp));
extern void	dumpInfo __((struct envelope *e));
extern void	dumpHeaders __((struct header *h));
extern void	dumpHeader __((struct header *h));
extern int	isSenderAddr;
extern int	isRecpntAddr;
extern void	squirrel __((struct envelope *e, char *text));
extern struct header	*erraddress __((struct envelope *e));
extern void	reject __((struct envelope *e, char *msgfile));
extern void	defer __((struct envelope *e));
extern struct header	*mkSender __((struct envelope *e, u_char *name, int flag));
extern struct header	*mkTrace __((struct envelope *e));
extern int	nullhost __((u_char *s));
extern struct conscell	*pickaddress __((struct conscell *l));
extern int	thesender __((struct envelope *e, struct address *a));
extern struct conscell	*makequad __((void));
extern int	iserrmessage __((void));
extern int	sequencer __((struct envelope *e, char *file));

/* File: rfc822hdrs.c */
extern union misc	 hdr_scanparse __((struct envelope *e, struct header *h, int commentflag));
extern struct header	*makeHeader __((struct sptree *db, u_char *s, int len));
extern struct headerinfo *senderDesc __((void));
extern void	set_pname __((struct envelope *e, struct header *h, char *s));
extern struct header	*copySender __((struct envelope *e));
extern struct header	*copyRecipient __((struct header *h));
extern struct header	*mkMessageId __((struct envelope *e, time_t unixtime));
extern struct header	*mkToHeader  __((struct envelope *e, const char *buf));
extern struct header	*mkDate __((int isresent, time_t unixtime));
extern void	hdr_print __((struct header *h, FILE *fp));
extern int	hdr_nilp __((struct header *h));
extern void	pureAddress __((FILE *fp, struct addr *pp));
extern int	printAddress __((FILE *fp, struct addr *pp, int onlylength));
extern int	printLAddress __((FILE *fp, struct addr *pp, int col));
extern char    *saveAddress __((struct addr *pp));
extern void	errprint __((FILE *fp, struct addr *pp, int hdrlen));
extern HeaderStamp hdr_type __((struct header *h));
extern struct header	*hdr_warning __((struct header *h));
extern void	hdr_errprint __((struct envelope *e, struct header *h, FILE *fp, char *msg));

/* File: rfc822walk.c */
extern struct address	*revaddress __((struct address *ap));
extern union misc	 parse822 __((HeaderSemantics entry, struct token **tlistp, struct tm *ltm, FILE *tfp));


/* File: router.c */
extern char *progname;
extern char *mailshare;
extern char *myhostname;
extern time_t now;
extern memtypes stickymem;
extern int   mustexit;
extern int   canexit;
extern int   deferit;
extern int   router_id;
extern int   savefile;

extern int	main __((int argc, char *argv[]));
extern int	login_to_uid __((u_char *name));
extern u_char	*uidpwnam __((int uid));
extern int	isgoodguy __((int uid));
extern void	logmessage __((struct envelope *e));

/* File: shliase.c */
extern int	s_apply __((int argc, char *argv[]));
extern int	n_apply __((char **cpp, int argc, char *argv[]));
extern struct header *hdr_rewrite __((u_char *name, struct header *h));
extern void	setenvinfo __((struct envelope *e));
extern struct conscell *router __((struct address *a, int uid, char *type));
extern struct conscell *crossbar __((struct conscell *from, struct conscell *to));

/* File: version.c */
extern char *Version;
extern char *CC_user;
extern char *CC_pwd;
